/* Copyright (c) 2016 Jaroslav Škarvada <jskarvad@redhat.com>
 * Based on CSV formatter code by Igor Zhbanov <i.zhbanov@samsung.com>
 *
 * This file is part of PowerTOP
 *
 * This program file is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program in a file named COPYING; if not, write to the
 * Free Software Foundation, Inc,
 * 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 * or just google for it.
 */

#define _BSD_SOURCE

/* Uncomment to disable asserts */
/*#define NDEBUG*/

#include <stdio.h>
#include <assert.h>
#include <stdarg.h>

#include "report-formatter-plain.h"

static const char report_plain_header[] = "PowerTOP Report";

/* ************************************************************************ */

report_formatter_plain::report_formatter_plain()
{
	add_doc_header();
}

/* ************************************************************************ */

void
report_formatter_plain::finish_report()
{
	/* Do nothing special */
}

/* ************************************************************************ */

void
report_formatter_plain::add_doc_header()
{
	add_header(report_plain_header, 1);
}

/* ************************************************************************ */

void
report_formatter_plain::add_header(const char *header, int level)
{
	assert(header);

	addf("%.*s%s%.*s", 4 - level, "===", header, 4 - level, "===");
	add_exact("\n");
}

/* ************************************************************************ */

void
report_formatter_plain::begin_section(section_type stype)
{
	/* Do nothing special */
}

/* ************************************************************************ */

void
report_formatter_plain::end_section()
{
	/* Do nothing special */
}

/* ************************************************************************ */

void
report_formatter_plain::begin_table(table_type ttype)
{
	add_exact("\n");
}

/* ************************************************************************ */

void
report_formatter_plain::end_table()
{
	add_exact("\n");
}

/* ************************************************************************ */

void
report_formatter_plain::begin_row(row_type rtype)
{
	table_cell_number = 0;
}

/* ************************************************************************ */

void
report_formatter_plain::end_row()
{
	add_exact("\n");
}

/* ************************************************************************ */

void
report_formatter_plain::begin_cell(cell_type ctype)
{
	if (table_cell_number > 0)
		add_exact(" ");
}

/* ************************************************************************ */

void
report_formatter_plain::end_cell()
{
	table_cell_number++;
}

/* ************************************************************************ */

void
report_formatter_plain::add_empty_cell()
{
	/* Do nothing special */
}

/* ************************************************************************ */

void
report_formatter_plain::begin_paragraph()
{
	/* Do nothing special */
}

/* ************************************************************************ */

void
report_formatter_plain::end_paragraph()
{
	add_exact("\n");
}

/* ************************************************************************ */

std::string
report_formatter_plain::escape_string(const char *str)
{
	assert(str);
	return std::string(str);
}

/* ************************************************************************ */

void
report_formatter_plain::set_cpu_number(int nr UNUSED)
{
	/* Do nothing */
}
